# DBnomics Web API

DBnomics Web API is deployed under `https://api.db.nomics.world/v22`.

## Documentation and playground

The Web API endpoints are documented [here](https://api.db.nomics.world/v22/apidocs). You can test them from this page.

Some background: DBnomics Web API describes its endpoints following the [OpenAPI Specification](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md) in [YAML files](./dbnomics_api/openapi_specs). The specs are exposed as a JSON file at `/apispec_1.json`.

## Development

### Install

If you want to run the Web API on your machine, for example to improve it, please follow the instructions below.

```bash
git clone https://git.nomics.world/dbnomics/dbnomics-api.git
cd dbnomics-api
python -m venv .venv
source .venv/bin/activate
pip install -r requirements.txt
pip install -r requirements-dev.txt
pip install --editable .[test]
```

### Configure

```bash
cp .env.example .env
```

Note: the default values are defined in `dbnomics_api/settings.py`.

The "Run DBnomics Docker stack" section below explains how to populate the directory referenced by `JSON_DATA_BASE_DIR`.

### Run development server

Run the application with Flask HTTP server:

```bash
flask run
```

The server runs on http://127.0.0.1:5000/

### Run DBnomics Docker stack

DBnomics web API needs an [Apache Solr](http://lucene.apache.org/solr/) instance to send queries to.

The [dbnomics-docker](https://git.nomics.world/dbnomics/dbnomics-docker) project enables running a local DBnomics stack. It is designed to run a subset of the services: in our case we'll run the web API with the Flask development server, and `solr` and `website` with the Docker stack.

Follow the instructions of [dbnomics-docker](https://git.nomics.world/dbnomics/dbnomics-docker) to install it, configure its `.env` file, run and access the services of DBnomics.

Be sure to run only `solr` and `website` with:

```bash
docker-compose up -- solr website
```

Check also that the `JSON_DATA_BASE_DIR` env variable of `.env` points to the `../dbnomics-docker/json-data` directory.

Now you can access the website at http://localhost:3000 and the local API at http://localhost:5000.

### Run tests

Please note that tests need Apache Solr to run.

```bash
pytest
```

### Check code quality

```bash
flake8
```

### Validate OpenAPI YAML specifications

To validate the OpenAPI YAML [specification files](./dbnomics_api/openapi_specs), use the [online Swagger validator](https://github.com/swagger-api/validator-badge) like this:

```bash
curl http://localhost:5000/apispec_1.json | curl -X POST -d @- -H 'Content-Type:application/json' http://online.swagger.io/validator/debug
```

If the specifications are valid, the output should be:

```bash
{}
```

Tip: for better readability you can add `| jq .` at the end of the line, to reformat the JSON using [jq](https://stedolan.github.io/jq/).

## Deploy to production

See https://git.nomics.world/dbnomics-fetchers/documentation/wikis/production-configuration

Before deploying a new version:

- update [CHANGELOG.md](./CHANGELOG.md)
- check that [dbnomics-ui](https://git.nomics.world/dbnomics/dbnomics-ui) and [dbnomics-python-client](https://git.nomics.world/dbnomics/dbnomics-python-client) work with this version, and update the required versions numbers
- tag the Git commit (`git tag x.y.z` then `git push --tags`)

After deploying a new version:

- post a message on [DBnomics forum](http://forum.db.nomics.world/)
