# dbnomics-api -- DBnomics Web API
# By: DBnomics Team <christophe.benz@cepremap.org>
#
# Copyright (C) 2017, 2018 Cepremap
# https://git.nomics.world/dbnomics/dbnomics-api
#
# dbnomics-api is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# dbnomics-api is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


"""Storage related functions, wrapping errors and raising HTTP errors."""


import logging

from dbnomics_data_model.exceptions import StorageError

from .json_errors import abort_json

logger = logging.getLogger(__name__)


def init_storage_or_abort(args, provider_code):
    from . import app  # Delay import to avoid cyclic imports.

    try:
        storage = app.storage_factory.create_storage_for_provider(provider_code)
    except StorageError:
        message = f"Could not find provider {provider_code!r}"
        logger.exception(message)
        abort_json(404, args, message)
    return storage


def load_dataset_json_or_abort(status, args, storage, dataset_code, dataset_dir=None):
    if dataset_dir is None:
        dataset_dir = storage.load_dataset_dir(dataset_code)
    try:
        return dataset_dir.load_dataset_json()
    except StorageError as exc:
        abort_json(status, args, str(exc))
