# dbnomics-api -- DBnomics Web API
# By: DBnomics Team <christophe.benz@cepremap.org>
#
# Copyright (C) 2017, 2018 Cepremap
# https://git.nomics.world/dbnomics/dbnomics-api
#
# dbnomics-api is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# dbnomics-api is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


"""General purpose functions."""

import unicodedata

from toolz import keyfilter


def normalize_string(s):
    """Normalize string, i.e. removing accents and turning into lowercase.
    It can be used to generate a sortable key.
    """
    return "".join(
        c
        for c in unicodedata.normalize("NFD", s.lower())
        if unicodedata.category(c) != "Mn"
    )


def omit(blacklist, d):
    """Return a subset of the provided dictionary with keys not contained in the blacklist.

    From https://toolz.readthedocs.io/en/latest/tips-and-tricks.html#omit

    >>> alphabet = {'a': 1, 'b': 2, 'c': 3, 'd': 4}
    >>> omit(['a', 'b'], alphabet).get('a')
    >>> omit(['a', 'b'], alphabet).get('b')
    >>> omit(['a', 'b'], alphabet).get('c')
    3
    >>> omit(['a', 'b'], alphabet).get('d')
    4
    """
    return keyfilter(lambda k: k not in blacklist, d)


def pick(whitelist, d):
    """Return a subset of the provided dictionary with keys contained in the whitelist.

    From https://toolz.readthedocs.io/en/latest/tips-and-tricks.html#pick

    >>> alphabet = {'a': 1, 'b': 2, 'c': 3, 'd': 4}
    >>> pick(['a', 'b'], alphabet).get('a')
    1
    >>> pick(['a', 'b'], alphabet).get('b')
    2
    >>> pick(['a', 'b'], alphabet).get('c')
    >>> pick(['a', 'b'], alphabet).get('d')
    """
    return keyfilter(lambda k: k in whitelist, d)


def without_none_values(d):
    return {k: v for k, v in d.items() if v is not None}
